==> pointpos_api-0.0.13.tar.gz: lib/api/recipe_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/recipe.dart';

part 'recipe_api.jretro.dart';

@GenApiClient()
class RecipeApi extends ApiClient with _$RecipeApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    RecipeApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Recipe
    ///
    /// Create Recipe
    @PostReq(path: "/recipe", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Recipe> createRecipe(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Recipe body
        ) {
        return super.createRecipe(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Recipe By ID
    ///
    /// Delete Recipe By ID
    @DeleteReq(path: "/recipe/:itemId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteRecipeByID(
            @PathParam("itemId") String itemId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteRecipeByID(
        itemId
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Recipe List
    ///
    /// Get Recipe  List
    @GetReq(path: "/recipe", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Recipe>> findRecipe(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findRecipe(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Recipe By ID
    ///
    /// Get Recipe By ID
    @GetReq(path: "/recipe/:itemId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Recipe> getRecipeByID(
            @PathParam("itemId") String itemId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getRecipeByID(
        itemId
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Recipe By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/recipe/:itemId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Recipe> updateRecipeByID(
            @PathParam("itemId") String itemId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Recipe body
        ) {
        return super.updateRecipeByID(
        itemId
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}

==> pointpos_api-0.0.16.tar.gz: lib/api/recipe_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/recipe.dart';

part 'recipe_api.jretro.dart';

@GenApiClient()
class RecipeApi extends ApiClient with _$RecipeApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    RecipeApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Recipe
    ///
    /// Create Recipe
    @PostReq(path: "/recipe", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Recipe> createRecipe(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Recipe body
        ) {
        return super.createRecipe(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Recipe By ID
    ///
    /// Delete Recipe By ID
    @DeleteReq(path: "/recipe/:itemId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteRecipeByID(
            @PathParam("itemId") String itemId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteRecipeByID(
        itemId
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Recipe List
    ///
    /// Get Recipe  List
    @GetReq(path: "/recipe", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Recipe>> findRecipe(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findRecipe(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Recipe By ID
    ///
    /// Get Recipe By ID
    @GetReq(path: "/recipe/:itemId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Recipe> getRecipeByID(
            @PathParam("itemId") String itemId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getRecipeByID(
        itemId
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Recipe By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/recipe/:itemId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Recipe> updateRecipeByID(
            @PathParam("itemId") String itemId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Recipe body
        ) {
        return super.updateRecipeByID(
        itemId
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
